@@ -2,8 +2,8 @@ import os
 import sys
 import asyncio
 
-from config import client
-from config.auth import Configuration
+from aiozoom.config import client
+from aiozoom.config.auth import Configuration
 
 
 class Base(Configuration):
