@@ -1,4 +1,4 @@
-from components.base import Base
+from aiozoom.components.base import Base
 
 
 class Dashboard(Base):
