@@ -1,8 +1,8 @@
 import asyncio
 import sys
 
-from components.base import Base
-from config import client
+from aiozoom.components.base import Base
+from aiozoom.config import client
 
 
 class Meeting(Base):
